@@ -4,4 +4,7 @@ from univariate.missing_value.handler.strategy.median_imputation import MedianIm
 from univariate.missing_value.handler.strategy.mode_imputation import ModeImputation
 from univariate.missing_value.handler.strategy.locf_imputation import LOCFImputation
 from univariate.missing_value.handler.strategy.bocf_imputation import BOCFImputation
+from univariate.missing_value.handler.strategy.linear_interploation import LinearInterpolation
+from univariate.missing_value.handler.strategy.lagrange_interpolation import LagrangeInterpolation
+from univariate.missing_value.handler.strategy.cubic_spline_interpolation import CubicSplineInterpolation
 from univariate.missing_value.handler.strategy.deletion import Deletion
